[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

r1032 - linux-kernel-headers/trunk/debian



Author: dan
Date: 2005-10-13 19:26:48 +0000 (Thu, 13 Oct 2005)
New Revision: 1032

Modified:
   linux-kernel-headers/trunk/debian/changelog
   linux-kernel-headers/trunk/debian/generate-asm.sh
Log:
  * Temporarily adjust i386 biarch support to avoid clashing with
    amd64-libs-dev (due to limitations of dpkg-divert).


Modified: linux-kernel-headers/trunk/debian/changelog
===================================================================
--- linux-kernel-headers/trunk/debian/changelog	2005-10-13 19:20:52 UTC (rev 1031)
+++ linux-kernel-headers/trunk/debian/changelog	2005-10-13 19:26:48 UTC (rev 1032)
@@ -5,8 +5,10 @@
     (Closes: #327779).
   * Add patch from Andreas Jochens <aj@andaco.de> for biarch ppc / ppc64 /
     i386 / amd64 support (Closes: #274920, #321969).
+  * Temporarily adjust i386 biarch support to avoid clashing with
+    amd64-libs-dev (due to limitations of dpkg-divert).
 
- -- Daniel Jacobowitz <dan@debian.org>  Thu, 13 Oct 2005 15:00:08 -0400
+ -- Daniel Jacobowitz <dan@debian.org>  Thu, 13 Oct 2005 15:26:31 -0400
 
 linux-kernel-headers (2.6.13+0rc3-1.1) unstable; urgency=low
 

Modified: linux-kernel-headers/trunk/debian/generate-asm.sh
===================================================================
--- linux-kernel-headers/trunk/debian/generate-asm.sh	2005-10-13 19:20:52 UTC (rev 1031)
+++ linux-kernel-headers/trunk/debian/generate-asm.sh	2005-10-13 19:26:48 UTC (rev 1032)
@@ -23,6 +23,7 @@
 		kernel_arch="i386"
 		kernel_arch_biarch="x86_64"
 		arch_biarch="amd64"
+		asm_dir_out="asm-i486"
 		;;
 	powerpc)
 		define_biarch="#ifdef __powerpc64__"
@@ -50,13 +51,19 @@
 asm_dir="asm-$kernel_arch"
 asm_dir_biarch="asm-$kernel_arch_biarch"
 
+# The directory to create in /usr/include.  This ought to be the same as
+# asm_dir in all cases, but is temporarily different on i386, so that we
+# can avoid conflicting between amd64-libs-dev and linux-kernel-headers
+# while headers transition from that package to this one.
+[ -z "$asm_dir_out" ] && asm_dir_out="$asm_dir"
+
 if [ ! -d "$dir_in/$asm_dir" ] || [ ! -d "$dir_in/$asm_dir_biarch" ] ; then
 	echo E: $asm_dir and $asm_dir_biarch must exist, or you will have problems
 	exit 1
 fi
 
 mkdir -p $dir_out/asm
-cp -a $dir_in/$asm_dir $dir_out/$asm_dir
+cp -a $dir_in/$asm_dir $dir_out/$asm_dir_out
 cp -a $dir_in/$asm_dir_biarch $dir_out/$asm_dir_biarch
 
 dirs=$((( cd "$dir_in/$asm_dir"; find . -type d ); ( cd "$dir_in/$asm_dir_biarch"; find . -type d )) | sort -u )
@@ -72,7 +79,7 @@
 	# common header
 	cat > $file_out << EOF
 /* All asm/ files are generated and point to the corresponding
  * file in $asm_dir or $asm_dir_biarch.
  */
 
 EOF
@@ -83,7 +90,7 @@
 $define_biarch
 # include <$asm_dir_biarch/$h>
 #else
-# include <$asm_dir/$h>
+# include <$asm_dir_out/$h>
 #endif
 EOF
 
@@ -92,7 +99,7 @@
 $define_biarch
 # error This header is not available for $kernel_arch_biarch
 #else
-# include <$asm_dir/$h>
+# include <$asm_dir_out/$h>
 #endif
 EOF
 	else
@@ -108,24 +115,24 @@
 done
 
 
-if [ -f $dir_out/$asm_dir/autoconf.h ] || [ -f $dir_out/$asm_dir_biarch/autoconf.h ]; then
-	echo E: $asm_dir or $asm_dir_biarch already have autoconf.h.
+if [ -f $dir_out/$asm_dir_out/autoconf.h ] || [ -f $dir_out/$asm_dir_biarch/autoconf.h ]; then
+	echo E: $asm_dir_out or $asm_dir_biarch already have autoconf.h.
 	exit 1
 fi
 
-cp "$autoconf_in"/autoconf-"$arch".h $dir_out/$asm_dir/autoconf.h
+cp "$autoconf_in"/autoconf-"$arch".h $dir_out/$asm_dir_out/autoconf.h
 cp "$autoconf_in"/autoconf-"$arch_biarch".h $dir_out/$asm_dir_biarch/autoconf.h
 
 file_out="$dir_out/linux/autoconf.h"
 h=autoconf.h
 cat > $file_out <<EOF
 /* linux/autoconf.h is generated and point to the corresponding
  * file in $asm_dir or $asm_dir_biarch.
  */
 
 $define_biarch
 # include <$asm_dir_biarch/$h>
 #else
-# include <$asm_dir/$h>
+# include <$asm_dir_out/$h>
 #endif
 EOF
@@ -72,7 +79,7 @@
 	cat > $file_out << EOF
 /* All asm/ files are generated and point to the corresponding
- * file in $asm_dir or $asm_dir_biarch.
+ * file in $asm_dir_out or $asm_dir_biarch.
  */
 
@@ -108,24 +115,24 @@
 cat > $file_out <<EOF
 /* linux/autoconf.h is generated and point to the corresponding
- * file in $asm_dir or $asm_dir_biarch.
+ * file in $asm_dir_out or $asm_dir_biarch.
  */
 



Reply to: